==> chromium-45.0.2419.0.tar.xz: chromium-45.0.2419.0/ui/keyboard/keyboard_switches.cc <==
// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ui/keyboard/keyboard_switches.h"

namespace keyboard {
namespace switches {

const char kEnableSwipeSelection[] = "enable-swipe-selection";

const char kDisableInputView[] = "disable-input-view";
const char kEnableInputView[] = "enable-input-view";
const char kEnableExperimentalInputViewFeatures[] =
    "enable-experimental-input-view-features";
const char kDisableVoiceInput[] = "disable-voice-input";
const char kDisableNewMDInputView[] = "disable-new-md-input-view";

const char kGestureTyping[] = "gesture-typing";
const char kGestureTypingEnabled[] = "enabled";
const char kGestureTypingDisabled[] = "disabled";

const char kGestureEditing[] = "gesture-editing";
const char kGestureEditingEnabled[] = "enabled";
const char kGestureEditingDisabled[] = "disabled";

const char kEnableVirtualKeyboard[] = "enable-virtual-keyboard";
const char kFloatingVirtualKeyboard[] = "floating-virtual-keyboard";
const char kFloatingVirtualKeyboardDisabled[] ="disabled";
const char kFloatingVirtualKeyboardEnabled[] ="enabled";
const char kDisableSmartVirtualKeyboard[] = "disable-smart-virtual-keyboard";

const char kDisableVirtualKeyboardOverscroll[] =
    "disable-virtual-keyboard-overscroll";
const char kEnableVirtualKeyboardOverscroll[] =
    "enable-virtual-keyboard-overscroll";

}  // namespace switches
}  // namespace keyboard

==> chromium-45.0.2424.0.tar.xz: chromium-45.0.2424.0/ui/keyboard/keyboard_switches.cc <==
// Copyright (c) 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ui/keyboard/keyboard_switches.h"

namespace keyboard {
namespace switches {

const char kEnableSwipeSelection[] = "enable-swipe-selection";

const char kDisableInputView[] = "disable-input-view";
const char kEnableInputView[] = "enable-input-view";
const char kEnableExperimentalInputViewFeatures[] =
    "enable-experimental-input-view-features";
const char kDisableVoiceInput[] = "disable-voice-input";
const char kDisableNewMDInputView[] = "disable-new-md-input-view";

const char kGestureTyping[] = "gesture-typing";
const char kGestureTypingEnabled[] = "enabled";
const char kGestureTypingDisabled[] = "disabled";

const char kGestureEditing[] = "gesture-editing";
const char kGestureEditingEnabled[] = "enabled";
const char kGestureEditingDisabled[] = "disabled";

const char kEnableVirtualKeyboard[] = "enable-virtual-keyboard";
const char kFloatingVirtualKeyboard[] = "floating-virtual-keyboard";
const char kFloatingVirtualKeyboardDisabled[] ="disabled";
const char kFloatingVirtualKeyboardEnabled[] ="enabled";

const char kSmartVirtualKeyboard[] = "smart-virtual-keyboard";
const char kSmartVirtualKeyboardDisabled[] = "disabled";
const char kSmartVirtualKeyboardEnabled[] = "enabled";

const char kDisableVirtualKeyboardOverscroll[] =
    "disable-virtual-keyboard-overscroll";
const char kEnableVirtualKeyboardOverscroll[] =
    "enable-virtual-keyboard-overscroll";

}  // namespace switches
}  // namespace keyboard
